==> WeaponButtons_v0.02.zip: Interface/AddOns/WeaponButtons/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_WEAPONBUTTONSHEADER					= "Weapon Buttons";
BINDING_NAME_WEAPONBUTTONS							= "Weapon Buttons Toggle";

WEAPONBUTTONS_CONFIG_HEADER							= "Weapon Buttons";
WEAPONBUTTONS_CONFIG_HEADER_INFO					= "Contains settings for the Weapon Buttons,\nan AddOn which allows you to get access to just the weapon buttons of the character window.";

WEAPONBUTTONS_ENABLED								= "Enable Weapon Buttons";
WEAPONBUTTONS_ENABLED_INFO							= "Enables Weapon Buttons, which means that the Weapon Buttons window will be displayed.";

WEAPONBUTTONS_CHAT_ENABLED							= "Weapon Buttons enabled.";
WEAPONBUTTONS_CHAT_DISABLED							= "Weapon Buttons disabled.";

WEAPONBUTTONS_CHAT_COMMAND_ENABLE_INFO				= "Enables/disables Weapon Buttons.";

WEAPONBUTTONS_DISPLAY_TOOLTIPS						= "Show tooltips on Weapon Buttons";
WEAPONBUTTONS_DISPLAY_TOOLTIPS_INFO					= "Determines whether tooltips should be shown on mousing over the WeaponButtons.";

WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_ENABLED			= "Weapon Buttons enabled.";
WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_DISABLED		= "Weapon Buttons disabled.";

WEAPONBUTTONS_CHAT_COMMAND_DISPLAY_TOOLTIPS_INFO	= "Enables/disables the showing of tooltips when mousing over Weapon Buttons.";

WEAPONBUTTONS_RESET									= "Reset position";
WEAPONBUTTONS_RESET_INFO							= "Resets the WeaponButtons position in case it's disappeared from the screen.";
WEAPONBUTTONS_RESET_NAME							= "Reset";
WEAPONBUTTONS_CHAT_COMMAND_RESET_INFO				= "Resets the position of the Weapon Buttons frame.";

==> WeaponButtons_v0.04.zip: Interface/AddOns/WeaponButtons/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_WEAPONBUTTONSHEADER					= "Weapon Buttons";
BINDING_NAME_WEAPONBUTTONS							= "Weapon Buttons Toggle";

WEAPONBUTTONS_CONFIG_HEADER							= "Weapon Buttons";
WEAPONBUTTONS_CONFIG_HEADER_INFO					= "Contains settings for the Weapon Buttons,\nan AddOn which allows you to get access to just the weapon buttons of the character window.";

WEAPONBUTTONS_ENABLED								= "Enable Weapon Buttons";
WEAPONBUTTONS_ENABLED_INFO							= "Enables Weapon Buttons, which means that the Weapon Buttons window will be displayed.";

WEAPONBUTTONS_CHAT_ENABLED							= "Weapon Buttons enabled.";
WEAPONBUTTONS_CHAT_DISABLED							= "Weapon Buttons disabled.";

WEAPONBUTTONS_CHAT_COMMAND_ENABLE_INFO				= "Enables/disables Weapon Buttons.";

WEAPONBUTTONS_DISPLAY_TOOLTIPS						= "Show tooltips on Weapon Buttons";
WEAPONBUTTONS_DISPLAY_TOOLTIPS_INFO					= "Determines whether tooltips should be shown on mousing over the WeaponButtons.";

WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_ENABLED			= "Weapon Buttons display of tooltips enabled.";
WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_DISABLED		= "Weapon Buttons display of tooltips disabled.";

WEAPONBUTTONS_CHAT_COMMAND_DISPLAY_TOOLTIPS_INFO	= "Enables/disables the showing of tooltips when mousing over Weapon Buttons.";

WEAPONBUTTONS_RESET									= "Reset position";
WEAPONBUTTONS_RESET_INFO							= "Resets the WeaponButtons position in case it's disappeared from the screen.";
WEAPONBUTTONS_RESET_NAME							= "Reset";
WEAPONBUTTONS_CHAT_COMMAND_RESET_INFO				= "Resets the position of the Weapon Buttons frame.";
